@@ -19,7 +19,7 @@ nK <- max(length(S), length(T), length(P), length(ks))
 if(length(S)!=nK){S <- rep(S[1], nK)}
 if(length(T)!=nK){T <- rep(T[1], nK)}
 if(length(P)!=nK){P <- rep(P[1], nK)}
-if(length(ks)!=nK){P <- rep(ks[1], nK)}
+if(length(ks)!=nK){ks <- rep(ks[1], nK)}
 
 #-------Constantes----------------
 
@@ -57,7 +57,7 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
 	lnKs = tmp1 + tmp2 + tmp3 + tmp4 + log(1-0.001005*S);
 		
 	Ks_d = exp(lnKs);
-	
+
 	#--------------------------------------------------------------
 	#------------------ Ks ----------------------------------------
 	#       Khoo et al. 1977
@@ -84,55 +84,12 @@ bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94
   for(i in 1:nK){
   if(ks[i]=="k"){ Ks[i] <- Ks_k[i]
   method[i] <- "Khoo et al. (1977)"
-  if((T<5)|(T>40)|(S<20)|(S>45)) {warning("S and/or T is outside the range of validity of the formulation chosen for Ks.")} }
+  if((T[i]<5)|(T[i]>40)|(S[i]<20)|(S[i]>45)) {warning("S and/or T is outside the range of validity of the formulation chosen for Ks.")} }
   }
 
 # ------------------- Pression effect --------------------------------
-for(i in (1:nK)){
 
-if (P[i] > 0.0)
-{
-		
-	RGAS = 8.314510;        # J mol-1 deg-1 (perfect Gas)  
-	R = 83.14472;             # mol bar deg-1 
-	                        # conversion cm3 -> m3          *1.e-6
-        	                  #            bar -> Pa = N m-2  *1.e+5
-	                        #                => *1.e-1 or *1/10
-		
-		
-	# index: K1 1, K2 2, Kb 3, Kw 4, Ks 5, Kf 6, Kspc 7, Kspa 8,
-	#        K1P 9, K2P 10, K3P 11
-	
-	#----- note: there is an error in Table 9 of Millero, 1995.
-	#----- The coefficients -b0 and b1
-	#----- have to be multiplied by 1.e-3!
-
-	#----- there are some more errors! 
-	#----- the signs (+,-) of coefficients in Millero 95 do not
-	#----- agree with Millero 79
-	
-		
-		
-	a0 = c(-25.5, -15.82, -29.48, -25.60, -18.03, -9.78, -48.76, -46, -14.51, -23.12, -26.57);
-	a1 = c(0.1271, -0.0219, 0.1622, 0.2324, 0.0466, -0.0090, 0.5304, 0.5304, 0.1211, 0.1758, 0.2020);
-	a2 = c(0.0, 0.0, 2.608*1e-3, -3.6246*1e-3, 0.316*1e-3, -0.942*1e-3, 0.0, 0.0, -0.321*1e-3, -2.647*1e-3, -3.042*1e-3);
-	b0 = c(-3.08*1e-3, 1.13*1e-3, -2.84*1e-3, -5.13*1e-3, -4.53*1e-3, -3.91*1e-3, -11.76*1e-3, -11.76*1e-3, -2.67*1e-3, -5.15*1e-3, -4.08*1e-3);
-	b1 = c(0.0877*1e-3, -0.1475*1e-3, 0.0, 0.0794*1e-3, 0.09*1e-3, 0.054*1e-3, 0.3692*1e-3, 0.3692*1e-3, 0.0427*1e-3, 0.09*1e-3, 0.0714*1e-3);
-	b2 = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
-	
-	deltav = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
-	deltak = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
-	lnkpok0 = c(0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0, 0.0);
-	
-	for (ipc in 1:length(a0))
-	{
-	  deltav[ipc]  =  a0[ipc] + a1[ipc] *T[i] + a2[ipc] *T[i]*T[i];
-	  deltak[ipc]   = (b0[ipc]  + b1[ipc] *T[i] + b2[ipc] *T[i]*T[i]);  
-	  lnkpok0[ipc]  = -(deltav[ipc] /(R*TK[i]))*P[i] + (0.5*deltak[ipc] /(R*TK[i]))*P[i]*P[i];
-	}
-
-	Ks[i] <- Ks[i]*exp(lnkpok0[5])
-}
+ Ks <- Pcorrect(Kvalue=Ks, Ktype="Ks", T=T, S=S, P=P, pHscale="F")
 
 ##------------Warnings
 
@@ -141,7 +98,7 @@ if((T[i]>45)|(S[i]>45)|(T[i]<0)|(S[i]<5)){warning("S and/or T is outside the ran
 }
 
 
-}
+
 attr(Ks,"unit") = "mol/kg-soln"	
 attr(Ks,"pH scale") = "free scale"
 attr(Ks, "method") = method
